#ifndef ERROR_H
#define ERROR_H

#include <libspotify/api.h>
#include <QString>

namespace Spotify
{
    class Error
    {
        public:
            Error();
            Error( sp_error error );
            QString toString() const;
            bool isError() const;

        private:
            sp_error m_error;
    };
} // namespace Spotify

#endif // ERROR_H
